@@ -34,7 +34,7 @@ use base qw/ Astro::FITS::HdrTrans::FITS /;
 
 use vars qw/ $VERSION /;
 
-$VERSION = "1.50";
+$VERSION = "1.56";
 
 # in each class we have three sets of data.
 #   - constant mappings
@@ -57,6 +57,10 @@ my %UNIT_MAP = (
 # Create the translation methods.
 __PACKAGE__->_generate_lookup_methods( \%CONST_MAP, \%UNIT_MAP );
 
+=head1 METHODS
+
+=over 4
+
 =item B<translate_from_FITS>
 
 This routine overrides the base class implementation to enable the
@@ -80,7 +84,7 @@ sub translate_from_FITS {
   return $class->SUPER::translate_from_FITS( $headers, @_ );
 }
 
-
+=back
 
 =head1 COMPLEX CONVERSIONS
 
@@ -218,10 +222,6 @@ sub _convert_sybase_date {
 
 =back
 
-=head1 REVISION
-
-$Id$
-
 =head1 SEE ALSO
 
 C<Astro::FITS::HdrTrans>, C<Astro::FITS::HdrTrans::Base>.
